package com.fs.app.controller;


import cn.hutool.json.JSONUtil;
import com.fs.app.annotation.Login;
import com.fs.app.vo.IndexVO;
import com.fs.common.core.domain.R;

import com.fs.his.domain.*;
import com.fs.his.param.*;
import com.fs.his.service.*;
import com.fs.his.vo.*;
import com.fs.store.domain.FsMenu;
import com.fs.store.domain.FsStoreCanvas;
import com.fs.store.param.FsArticleQueryParam;
import com.fs.store.service.IFsMenuService;
import com.fs.store.service.IFsStoreCanvasService;
import com.fs.store.service.IFsStoreCartService;
import com.fs.store.vo.FsAdvListQueryVO;
import com.fs.store.vo.FsArticleCateListQueryVO;
import com.fs.store.vo.FsArticleListQueryVO;
import com.fs.store.vo.FsStoreProductListQueryVO;
import com.fs.store.config.ConceptConfig;
import com.fs.system.service.ISysConfigService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;


@Api("首页接口")
@RestController
@RequestMapping(value="/app/index")
public class IndexController extends AppBaseController {

	@Autowired
	private IFsFamousPrescribeService fsFamousPrescribeService;

	@Autowired
	private IFsQuestionsService questionsService;

	@Autowired
	private IFsMedicatedFoodService medicatedFoodService;

	@Autowired
	private IFsVesselService vesselService;

	@Autowired
	private ISysConfigService configService;

	@Autowired
	private IFsChineseMedicineService chineseMedicineService;

	@Autowired
	private IFsStoreCanvasService storeCanvasService;

	@Autowired
	private IFsMenuService menuService;

	@Autowired
	private IFsArticleCateService articleCateService;

	@Autowired
	private IFsAdvService advService;

	@Autowired
	private IFsStoreProductService productService;


	@Autowired
	private IFsStoreCartService cartService;


	@Autowired
	private IFsArticleService articleService;

	@ApiOperation("获取名方列表")
	@Cacheable(value = "getFamousPrescribeList", key = "#param")
	@GetMapping("/getFamousPrescribeList")
	public R getFamousPrescribeList(FsFamousPrescribeListUParam param)
	{
		PageHelper.startPage(param.getPageNum(), param.getPageSize());
		List<FsFamousPrescribeListUVO> list=fsFamousPrescribeService.selectFsFamousPrescribeListUVO(param);
		PageInfo<FsFamousPrescribeListUVO> listPageInfo=new PageInfo<>(list);
		return R.ok().put("data",listPageInfo);
	}

	@GetMapping("/getFamousPrescribeById")
	@Cacheable(value = "getFamousPrescribeById", key = "#id")
	public R getFamousPrescribeById(@RequestParam("id")Long id)
	{
		FsFamousPrescribe fsFamousPrescribe=fsFamousPrescribeService.selectFsFamousPrescribeById(id);
		return R.ok().put("data",fsFamousPrescribe);
	}
	@ApiOperation("获取问答列表")
	@Cacheable(value = "getQuestionsList", key = "#param")
	@GetMapping("/getQuestionsList")
	public R getQuestionsList(FsQuestionsListUParam param)
	{
		PageHelper.startPage(param.getPageNum(), param.getPageSize());
		List<FsQuestionsListUVO> list=questionsService.selectFsQuestionsListUVO(param);
		PageInfo<FsQuestionsListUVO> listPageInfo=new PageInfo<>(list);
		return R.ok().put("data",listPageInfo);
	}

	@GetMapping("/getQuestionsById")
	@Cacheable(value = "getQuestionsById", key = "#id")
	public R getQuestionsById(@RequestParam("id")Long id)
	{
		FsQuestions questions=questionsService.selectFsQuestionsById(id);
		return R.ok().put("data",questions);
	}
	@ApiOperation("获取穴位列表")
	@GetMapping("/getVesselList")
	@Cacheable(value = "getVesselList", key = "#param")
	public R getVesselList(FsVesselListUParam param)
	{
		PageHelper.startPage(param.getPageNum(), param.getPageSize());
		List<FsVesselListUVO> list=vesselService.selectFsVesselListUVO(param);
		PageInfo<FsVesselListUVO> listPageInfo=new PageInfo<>(list);
		return R.ok().put("data",listPageInfo);
	}

	@GetMapping("/getVesselById")
	@Cacheable(value = "getVesselById", key = "#id")
	public R getVesselById(@RequestParam("id")Long id)
	{
		FsVessel vessel=vesselService.selectFsVesselById(id);
		return R.ok().put("data",vessel);
	}
	@ApiOperation("获取食谱列表")
	@GetMapping("/getMedicatedFoodList")
	@Cacheable(value = "getMedicatedFoodList", key = "#param")
	public R getMedicatedFoodList(FsMedicateFoodListUParam param)
	{
		PageHelper.startPage(param.getPageNum(), param.getPageSize());
		List<FsMedicateFoodListUVO> list=medicatedFoodService.selectFsMedicatedFoodListUVO(param);
		PageInfo<FsMedicateFoodListUVO> listPageInfo=new PageInfo<>(list);
		return R.ok().put("data",listPageInfo);
	}

	@GetMapping("/getMedicatedFoodById")
	@Cacheable(value = "getMedicatedFoodById", key = "#id")
	public R getMedicatedFoodById(@RequestParam("id")Long id)
	{
		FsMedicatedFood food=medicatedFoodService.selectFsMedicatedFoodById(id);
		return R.ok().put("data",food);
	}
	@ApiOperation("获取中医列表")
	@GetMapping("/getChineseMedicineList")
	@Cacheable(value = "getChineseMedicineList", key = "#param")
	public R getChineseMedicineList(FsChineseMedicineListUParam param)
	{
		PageHelper.startPage(param.getPageNum(), param.getPageSize());
		List<FsChineseMedicineListUVO> list=chineseMedicineService.selectFsChineseMedicineListUVO(param);
		PageInfo<FsChineseMedicineListUVO> listPageInfo=new PageInfo<>(list);
		return R.ok().put("data",listPageInfo);
	}

	@GetMapping("/getChineseMedicineById")
	@Cacheable(value = "getChineseMedicineById", key = "#id")
	public R getChineseMedicineById(@RequestParam("id")Long id)
	{
		FsChineseMedicine chineseMedicine=chineseMedicineService.selectFsChineseMedicineById(id);
		return R.ok().put("data",chineseMedicine);
	}

	@ApiOperation("读取画布数据")
	@GetMapping("/getCanvas")
	@springfox.documentation.annotations.Cacheable("canvas")
	public R getCanvas(HttpServletRequest request){
		FsStoreCanvas map=new FsStoreCanvas();
		map.setIsDel(0);
		map.setType(1);
		List<FsStoreCanvas> canvas=storeCanvasService.selectFsStoreCanvasList(map);
		return R.ok().put("data", canvas.get(0));
	}

	@ApiOperation("读取菜单数据")
	@GetMapping("/getMenu")
	@springfox.documentation.annotations.Cacheable("menu")
	public R getMenu(HttpServletRequest request){
		FsMenu map=new FsMenu();
		map.setIsShow(1);
		map.setMenuType(1);
		List<FsMenu> list=menuService.selectFsMenuList(map);
		return R.ok().put("data",list);
	}

	@ApiOperation("获取首页数据")
	@GetMapping("/getIndexData")
	public R getIndexData(HttpServletRequest request){
		List<FsArticleCateListQueryVO> articleCateList=articleCateService.selectFsArticleCateListQuery();
		List<FsAdvListQueryVO> advList=advService.selectFsAdvListQuery(1);
		List<FsStoreProductListQueryVO> newProductList=productService.selectFsStoreProductNewQuery(10);
		List<FsStoreProductListQueryVO> hotProductList=productService.selectFsStoreProductHotQuery(10);
		IndexVO vo= IndexVO.builder().articleCateList(articleCateList).advList(advList).newProductList(newProductList).hotProductList(hotProductList).build();
		return R.ok().put("data", vo);
	}
	@ApiOperation("企业理念")
	@GetMapping("/getConcept")
	@springfox.documentation.annotations.Cacheable("getConcept")
	public R getConcept(HttpServletRequest request){
		String json=configService.selectConfigByKey("store.concept");
		ConceptConfig config = JSONUtil.toBean(json, ConceptConfig.class);
		return R.ok().put("data",config);
	}

	@Login
	@ApiOperation("获取购物车数量")
	@GetMapping("/getCartCount")
	public R getCartCount(){
		Integer count=cartService.selectFsStoreCartCountByUserId(Long.parseLong(getUserId()));
		return R.ok().put("data", count);
	}

	@ApiOperation("获取推荐健康知识")
	@GetMapping("/getTuiArticle")
	public R getTuiArticle(FsArticleQueryParam param){

		List<FsArticleListQueryVO> list=articleService.selectFsArticleListQuery(param);
		return R.ok().put("data", list);
	}

}
